@@ -93,7 +93,7 @@ class MysqlHelper(Singleton):
                 return []
         except Exception as e:
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def Query(self, sql, *Param):
         try:
@@ -118,7 +118,7 @@ class MysqlHelper(Singleton):
                 return []
         except Exception as e:
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def QuerySingle(self, sql, *Param):
         try:
@@ -141,7 +141,7 @@ class MysqlHelper(Singleton):
                 return None
         except Exception as e:
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def QuerySingleT(self, sql, *Param):
         try:
@@ -164,7 +164,7 @@ class MysqlHelper(Singleton):
                 return None
         except Exception as e:
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def ExcuteSql(self, sql, *Param):
         conn = None
@@ -178,7 +178,7 @@ class MysqlHelper(Singleton):
         except Exception as e:
             conn.rollback()
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def ExecuteMany(self, sql, Param):
         conn = None
@@ -195,7 +195,7 @@ class MysqlHelper(Singleton):
         except Exception as e:
             conn.rollback()
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
 
 class PgHelper(Singleton2):
@@ -243,7 +243,7 @@ class PgHelper(Singleton2):
                 return []
         except Exception as e:
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def Query(self, sql, *Param):
         try:
@@ -269,7 +269,7 @@ class PgHelper(Singleton2):
                 return []
         except Exception as e:
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def QuerySingle(self, sql, *Param):
         try:
@@ -293,7 +293,7 @@ class PgHelper(Singleton2):
                 return None
         except Exception as e:
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def QuerySingleT(self, sql, *Param):
         try:
@@ -316,7 +316,7 @@ class PgHelper(Singleton2):
                 return None
         except Exception as e:
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def ExcuteSql(self, sql, *Param):
         conn = None
@@ -330,7 +330,7 @@ class PgHelper(Singleton2):
         except Exception as e:
             conn.rollback()
             self.Log.error(e)
-            raise Exception(e)
+            raise e
 
     def ExecuteMany(self, sql, Param):
         conn = None
@@ -347,4 +347,4 @@ class PgHelper(Singleton2):
         except Exception as e:
             conn.rollback()
             self.Log.error(e)
-            raise Exception(e)
+            raise e
