@@ -31,6 +31,12 @@ class LogHelper:
             return False
 
     def error(self, msg):
+        if isinstance(msg, str):
+            pass
+        if isinstance(msg, Exception):
+            if msg.__getattribute__("args"):
+                if isinstance(msg.args, tuple) or isinstance(msg.args, list):
+                    msg = '-'.join([str(v) for v in msg.args])
         msg = f"{datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')} {json.dumps(msg, ensure_ascii=False)}"
         flag = self.writeFile('error', msg)
         if flag:
